@@ -4,11 +4,12 @@
 # This is used to represent the option products and it will be contained to all the Option-related classes
 
 Option = setRefClass("Option",
-                  fields = list(OptionType      = 'character',
-                                UnderlyingPrice = 'numeric',
-                                StrikePrice     = 'numeric',
-                                del_type        = 'character',
-                                maturity        = 'numeric'
+                  fields = list(OptionType        = 'character',
+                                UnderlyingPrice   = 'numeric',
+                                StrikePrice       = 'numeric',
+                                del_type          = 'character',
+                                maturity          = 'numeric',
+                                exotic_opt_type   = 'character'
                   ),
                   methods = list(
                     CalcMaturity =function()
